import{Z as s,$ as a}from"./index-aHi_iQYn.js";const i="wifi_ssid",n="wifi_password",o=async()=>{const s=await a();return s.includes(i)&&s.includes(n)},r=async(a,o)=>s({[i]:a,[n]:o},"Your Wi-Fi SSID and password");export{n as S,i as a,o as c,r as s};
//# sourceMappingURL=c.D9tA-dPw.js.map
