import{S as s,E as a,a as e}from"../../../../c.CsuD-Bo9.js";let n=!1;globalThis.onmessage=o=>{n||function(o){if(n)return;n=!0;const l=new s((s=>{globalThis.postMessage(s)}),(s=>new a(e.getChannel(s),o)));globalThis.onmessage=s=>{l.onmessage(s.data)}}(null)};
//# sourceMappingURL=editor.worker.js.map
