import{U as t,V as i,t as s}from"./index-aHi_iQYn.js";const e=(t,i)=>{var s,n;const o=t._$AN;if(void 0===o)return!1;for(const t of o)null===(n=(s=t)._$AO)||void 0===n||n.call(s,i,!1),e(t,i);return!0},n=t=>{let i,s;do{if(void 0===(i=t._$AM))break;s=i._$AN,s.delete(t),t=i}while(0===(null==s?void 0:s.size))},o=t=>{for(let i;i=t._$AM;t=i){let s=i._$AN;if(void 0===s)i._$AN=s=new Set;else if(s.has(t))break;s.add(t),$(i)}};function l(t){void 0!==this._$AN?(n(this),this._$AM=t,o(this)):this._$AM=t}function h(t,i=!1,s=0){const o=this._$AH,l=this._$AN;if(void 0!==l&&0!==l.size)if(i)if(Array.isArray(o))for(let t=s;t<o.length;t++)e(o[t],!1),n(o[t]);else null!=o&&(e(o,!1),n(o));else e(this,t)}const $=t=>{var i,e,n,o;t.type==s.CHILD&&(null!==(i=(n=t)._$AP)&&void 0!==i||(n._$AP=h),null!==(e=(o=t)._$AQ)&&void 0!==e||(o._$AQ=l))};let _=class extends t{constructor(){super(...arguments),this._$AN=void 0}_$AT(t,i,s){super._$AT(t,i,s),o(this),this.isConnected=t._$AU}_$AO(t,i=!0){var s,o;t!==this.isConnected&&(this.isConnected=t,t?null===(s=this.reconnected)||void 0===s||s.call(this):null===(o=this.disconnected)||void 0===o||o.call(this)),i&&(e(this,t),n(this))}setValue(t){if(i(this._$Ct))this._$Ct._$AI(t,this);else{const i=[...this._$Ct._$AH];i[this._$Ci]=t,this._$Ct._$AI(i,this,0)}}disconnected(){}reconnected(){}};export{_ as c};
//# sourceMappingURL=c.B_bHDSZS.js.map
