import{b as e,n as s,s as l,x as o}from"./index-aHi_iQYn.js";import"./c.CsLtSInB.js";import"./c.DSo6oV4_.js";let d=class extends l{render(){return o`
      <esphome-process-dialog
        heading="Update All"
        .type=${"update-all"}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};d=e([s("esphome-update-all-dialog")],d);
//# sourceMappingURL=c.D2kKO1L2.js.map
